@@ -16,7 +16,7 @@
 
 package MongoDB::Connection;
 {
-  $MongoDB::Connection::VERSION = '0.502.1';
+  $MongoDB::Connection::VERSION = '0.503.1';
 }
 
 # ABSTRACT: A connection to a Mongo server
@@ -36,22 +36,16 @@ use boolean;
 has '_client' => (
     isa         => 'MongoDB::MongoClient', 
     is          => 'ro',
-    lazy_build  => 1,
-    handles     => [ grep { $_ !~ /^meta$/ } 
+    handles     => [ grep { $_ !~ /^(meta|new)$/ } 
                      map { $_->name } Class::MOP::Class->initialize( 'MongoDB::MongoClient' )->get_all_methods 
                    ]
 );
 
-sub _build__client { 
-    shift;
-    return MongoDB::MongoClient->new( @_ );
-}
 
-	
-
-__PACKAGE__->meta->make_immutable (inline_destructor => 0);
-
-1;
+around 'new' => sub { 
+    my ( $orig, $self, @args ) = @_;
+    return $self->$orig( _client => MongoDB::MongoClient->new( @args ) );
+};
 
 
 
@@ -67,6 +61,12 @@ sub AUTOLOAD {
     return $self->get_database($db);
 }
 
+
+
+__PACKAGE__->meta->make_immutable ( inline_destructor => 0, inline_constructor => 0 );
+
+1;
+
 __END__
 
 =pod
@@ -77,7 +77,7 @@ MongoDB::Connection - A connection to a Mongo server
 
 =head1 VERSION
 
-version 0.502.1
+version 0.503.1
 
 =head1 SYNOPSIS
 
