@@ -46,13 +46,21 @@ typedef __int64 int64_t;
 #define RX_PRELEN(re) ((re)->prelen)
 #endif
 
+#define SUBTYPE_BINARY_DEPRECATED 2
+#define SUBTYPE_BINARY 0
+
 #if MONGO_BIG_ENDIAN
+
 #define BYTE1_32(b) ((b & 0xff000000) >> 24)
 #define BYTE2_32(b) ((b & 0x00ff0000) >> 8)
 #define BYTE3_32(b) ((b & 0x0000ff00) << 8)
 #define BYTE4_32(b) ((b & 0x000000ff) << 24)
+
 #define MONGO_32(b) (BYTE4_32(b) | BYTE3_32(b) | BYTE2_32(b) | BYTE1_32(b))
 
+#define MONGO_32p(b) (((int)((unsigned char)b[0])) | ((int)((unsigned char)b[1]) << 8) | \
+                      ((int)((unsigned char)b[2]) << 16) | ((int)((unsigned char)b[3]) << 24))
+
 #define BYTE1_64(b) ((b & 0xff00000000000000ll) >> 56)
 #define BYTE2_64(b) ((b & 0x00ff000000000000ll) >> 40)
 #define BYTE3_64(b) ((b & 0x0000ff0000000000ll) >> 24)
@@ -61,11 +69,21 @@ typedef __int64 int64_t;
 #define BYTE6_64(b) ((b & 0x0000000000ff0000ll) << 24)
 #define BYTE7_64(b) ((b & 0x000000000000ff00ll) << 40)
 #define BYTE8_64(b) ((b & 0x00000000000000ffll) << 56)
-#define MONGO_64(b) (BYTE8_64(b) | BYTE7_64(b) | BYTE6_64(b) | BYTE5_64(b) | BYTE4_64(b) | BYTE3_64(b) | BYTE2_64(b) | BYTE1_64(b))
+
+#define MONGO_64(b) (BYTE8_64(b) | BYTE7_64(b) | BYTE6_64(b) | BYTE5_64(b) | \
+                     BYTE4_64(b) | BYTE3_64(b) | BYTE2_64(b) | BYTE1_64(b))
+
+#define MONGO_64p(b) (((int64_t)((unsigned char)b[0])) | ((int64_t)((unsigned char)b[1]) << 8) | \
+                      ((int64_t)((unsigned char)b[2]) << 16) | ((int64_t)((unsigned char)b[3]) << 24) | \
+                      ((int64_t)((unsigned char)b[4]) << 32) | ((int64_t)((unsigned char)b[5]) << 40) | \
+                      ((int64_t)((unsigned char)b[6]) << 48) | ((int64_t)((unsigned char)b[7]) << 56))
 
 #else
 #define MONGO_32(b) (b)
+#define MONGO_32p(b) *((int*)(b))
+
 #define MONGO_64(b) (b)
+#define MONGO_64p(b) *((int64_t*)(b))
 #endif
 
 
@@ -98,7 +116,7 @@ typedef __int64 int64_t;
 #define BSON_MAXKEY 127
 
 #define GROW_SLOWLY 1048576
-#define MAX_OBJ_SIZE 1024*1024*4
+#define MAX_OBJ_SIZE (1024*1024*4)
 
 typedef struct {
   char *start;
@@ -123,11 +141,8 @@ typedef struct _stackette {
 extern MGVTBL connection_vtbl, cursor_vtbl;
 extern int perl_mongo_machine_id;
 
-#ifdef WIN32
-// Windows requires initializing the mutex before using it.
+int isUTF8(const char*, int);
 void perl_mongo_mutex_init();
-#endif
-
 void perl_mongo_call_xs (pTHX_ void (*subaddr) (pTHX_ CV *cv), CV *cv, SV **mark);
 SV *perl_mongo_call_reader (SV *self, const char *reader);
 SV *perl_mongo_call_method (SV *self, const char *method, I32 flags, int num, ...);
@@ -142,7 +157,7 @@ void perl_mongo_make_id(char *id);
 void perl_mongo_make_oid(char* twelve, char *twenty4);
 
 // serialization
-SV *perl_mongo_bson_to_sv (buffer *buf);
+SV *perl_mongo_bson_to_sv (buffer *buf, char *dt_type);
 void perl_mongo_sv_to_bson (buffer *buf, SV *sv, AV *ids);
 
 int perl_mongo_resize_buf (buffer*, int);
